@@ -1,11 +1,10 @@
 from typing import List, Optional
 
-from pydantic import Field
-
-from nwon_django_toolbox.typings.pydantic_base_django import PydanticBaseDjango
+import humps
+from pydantic import BaseModel, Field
 
 
-class NWONDjangoSettings(PydanticBaseDjango):
+class NWONDjangoSettings(BaseModel):
     """
     Settings for the NWON-django-toolbox package.
 
@@ -38,5 +37,16 @@ class NWONDjangoSettings(PydanticBaseDjango):
         description="Application name that is used whenever needed",
     )
 
+    # Basically the same config as PydanticBaseDjango but we can't import because of a circular import problem
+    class Config:
+        # no additional properties
+        extra = "forbid"
+
+        # Allow initialization via attribute names and aliases
+        allow_population_by_field_name = True
+
+        # auto generate camelized aliases
+        alias_generator = humps.camelize
+
 
 __all__ = ["NWONDjangoSettings"]
